# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/person/ne_NP/__init__.py

person_formats_female_ne_np <- c(
  "{{first_names_female}} {{last_names}}",
  "{{first_names_female}} {{last_names}}",
  "{{first_names_female}} {{last_names}}",
  "{{first_names_female}} {{last_names}}",
  "{{first_names_female}} {{last_names}}",
  "{{prefixes_female}} {{first_names_female}} {{last_names}}"
)

person_formats_male_ne_np <- c(
  "{{first_names_male}} {{last_names}}",
  "{{first_names_male}} {{last_names}}",
  "{{first_names_male}} {{last_names}}",
  "{{first_names_male}} {{last_names}}",
  "{{first_names_male}} {{last_names}}",
  "{{prefixes_male}} {{first_names_male}} {{last_names}}"
)

person_formats_ne_np <- c(person_formats_male_ne_np, person_formats_female_ne_np)

person_first_names_female_ne_np <- c(
  "\u0905\u0902\u0917\u0941\u0930",
  "\u0905\u091c\u093f\u0924\u093e",
  "\u0905\u091e\u094d\u091c\u0928\u093e",
  "\u0905\u0926\u093f\u0924\u0940",
  "\u0905\u0928\u0927\u093e",
  "\u0905\u0928\u093f\u0924\u093e",
  "\u0905\u0928\u093f\u0924\u093e",
  "\u0905\u0928\u093f\u0924\u093e",
  "\u0905\u0928\u093f\u0924\u093e",
  "\u0905\u0928\u0941",
  "\u0905\u0928\u0941\u092a\u092e\u093e",
  "\u0905\u0928\u0941\u0930\u093e",
  "\u0905\u0928\u0941\u0936\u0941\u092f\u093e",
  "\u0905\u0928\u094d\u091c\u0932\u0940",
  "\u0905\u0928\u094d\n\u0928\u092a\u0942\u0930\u094d\u0923",
  "\u0905\u092a\u0930\u094d\u0923\u093e",
  "\u0905\u092e\u0930\u093e\u0935\u0924\u0940",
  "\u0905\u092e\u093f\u0915\u093e",
  "\u0905\u092e\u0943\u0924",
  "\u0905\u092e\u0943\u0924\u093e",
  "\u0905\u092e\u094d\u0935\u093f\u0915\u093e",
  "\u0905\u092e\u094d\u0935\u093f\u0915\u093e",
  "\u0905\u092e\u094d\u0935\u0940\u0915\u093e",
  "\u0905\u0930\u0941\u0923\u093e",
  "\u0905\u0930\u094d\u091a\u0928\u093e",
  "\u0905\u0930\u094d\u091a\u0928\u093e",
  "\u0905\u0930\u094d\u091a\u0928\u093e",
  "\u0905\u0930\u094d\u091a\u0928\u093e",
  "\u0905\u0938\u094d\n\u092e\u093f\u0924\u093e",
  "\u0906\u091c\u094d\u091e\u093e",
  "\u0906\u092d\u093e",
  "\u0906\u092f\u0941\u0937\u093e",
  "\u0906\u092f\u0941\u0937\u094d\n\u092e\u093e",
  "\u0906\u0935\u0943\u0924\u093e",
  "\u0906\u0936\u093e",
  "\u0907\u091a\u094d\u091b\u093e",
  "\u0907\u0928\u094d\u0926\u093f\u0930\u093e",
  "\u0907\u0928\u094d\u0926\u093f\u0930\u093e",
  "\u0907\u0928\u094d\u0926\u093f\u0930\u093e",
  "\u0907\u0928\u094d\u0926\u093f\u0930\u093e",
  "\u0907\u0928\u094d\u0926\u0940\u0930\u093e",
  "\u0907\u0928\u094d\u0926\u0941",
  "\u0907\u0928\u094d\u0926\u0941",
  "\u0907\u0928\u094d\u0926\u094d\u0930",
  "\u0907\u0928\u094d\u0926\u094d\u0930",
  "\u0907\u0928\u094d\n\u0926\u094d\u0930",
  "\u0907\u092d\u0928",
  "\u0907\u092d\u093e",
  "\u0907\u0936\u0941",
  "\u0908\u0924\u093e\u0938\u093e",
  "\u0908\u0928\u094d\u0926\u0941",
  "\u0908\u0932\u093e",
  "\u0908\u0936\u093e",
  "\u0908\u0936\u093e",
  "\u0908\u0936\u094d\n\u0935\u0930\u0940",
  "\u0908\u0936\u094d\n\u0935\u0930\u0940",
  "\u0908\u0936\u094d\n\u0935\u0930\u0940",
  "\u0909\u0924\u094d\u0924\u0930\u093e",
  "\u0909\u092a\u093e\u0938\u0928\u093e",
  "\u0909\u092e\u093e",
  "\u0909\u092e\u093e",
  "\u0909\u092e\u093e",
  "\u0909\u092e\u093e",
  "\u0909\u0930\u094d\u092e\u093f\u0932\u093e",
  "\u0909\u0930\u094d\u092e\u093f\u0932\u093e",
  "\u0909\u0930\u094d\u092e\u093f\u0932\u093e",
  "\u0909\u0937\u093e",
  "\u0909\u0937\u093e",
  "\u0909\u0937\u093e",
  "\u0909\u0937\u093e",
  "\u0909\u0937\u093e",
  "\u0909\u0937\u093e",
  "\u090f\u0932\u093f\u0936\u093e",
  "\u090f\u0932\u093f\u0938\u093e",
  "\u090f\u0932\u093f\u0938\u093e",
  "\u0910\u0930\u093f\u0915\u093e",
  "\u0915\u092e\u0932\u093e",
  "\u0915\u092e\u0932\u093e",
  "\u0915\u092e\u0932\u093e",
  "\u0915\u092e\u0932\u093e",
  "\u0915\u092e\u0932\u093e",
  "\u0915\u0930\u094d\u0938\u093e\u0919",
  "\u0915\u0932\u094d\u092a\u0928\u093e",
  "\u0915\u0935\u093f\u0924\u093e",
  "\u0915\u0935\u093f\u0924\u093e",
  "\u0915\u093e\u0928\u094d\u0924\u0940",
  "\u0915\u093e\u0928\u094d\n\u0924\u093e",
  "\u0915\u093e\u092e\u0928\u093e",
  "\u0915\u093e\u0932\u0938\u093e\u0919\u094d\u0917",
  "\u0915\u093f\u0930\u0923",
  "\u0915\u093f\u0930\u0923",
  "\u0915\u093f\u0930\u0923",
  "\u0915\u0941\u0938\u0941\u092e",
  "\u0915\u0943\u0924\u093f\u0915\u093e",
  "\u0915\u0943\u0937\u094d\u091f\u093f\u0928\u093e",
  "\u0915\u0943\u0937\u094d\u0923",
  "\u0915\u0943\u0937\u094d\u0923",
  "\u0915\u0943\u0937\u094d\u0923",
  "\u0915\u0943\u0937\u094d\u0923",
  "\u0915\u0943\u0937\u094d\n\u0923",
  "\u0915\u0943\u0937\u094d\n\u0923",
  "\u0915\u0947\u092e\u093e",
  "\u0915\u0947\u0936\u0930\u0940",
  "\u0915\u094b\u092e\u0932",
  "\u0917\u0902\u0917\u093e",
  "\u0917\u0902\u0917\u093e",
  "\u0917\u0902\u0917\u093e",
  "\u0917\u0923\u0947\u0936",
  "\u0917\u0930\u0940\u092e\u093e",
  "\u0917\u093e\u092f\u0924\u094d\u0930\u0940",
  "\u0917\u0940\u0924\u093e",
  "\u0917\u0940\u0924\u093e",
  "\u0917\u0940\u0924\u093e",
  "\u0917\u0940\u0924\u093e",
  "\u0917\u094c\u0930\u0940",
  "\u091a\u0923\u094d\u0921\u093f\u0915\u093e",
  "\u091a\u0928\u094d\u0926\u093e",
  "\u091a\u0928\u094d\u0926\u093e",
  "\u091a\u0928\u094d\u0926\u093e",
  "\u091a\u0928\u094d\u0926\u093e",
  "\u091a\u0928\u094d\u0926\u094d\u0930\u092e\u093e\u092f\u093e",
  "\u091a\u0928\u094d\u0926\u094d\u0930\u0932\u0915\u094d\u0937\u094d\u092e\u0940",
  "\u091a\u0928\u094d\u0926\u094d\u0930\u093e",
  "\u091a\u092e\u094d\u092a\u093e",
  "\u091a\u093e\u0901\u0926\u0928\u0940",
  "\u091a\u093f\u0928\u0940",
  "\u091a\u093f\u0928\u0940",
  "\u091a\u0941\u0928\u0941",
  "\u091a\u0941\u0930\u0940\u0928\u093e\u0928\u0940",
  "\u091b\u093f\u0930\u093f\u0919",
  "\u091b\u093f\u0930\u093f\u0919",
  "\u091b\u093f\u0930\u093f\u0919",
  "\u091b\u0941\u0919\u0921\u094d\u092f\u093e\u0915",
  "\u091b\u0947\u0924\u0928",
  "\u091b\u094b\u0915\u094d\u092a\u093e",
  "\u091c\u0924\u0928",
  "\u091c\u0928\u0915",
  "\u091c\u092e\u0941\u0928\u093e",
  "\u091c\u092e\u0941\u0928\u093e",
  "\u091c\u092f\u0936\u094d\u0930\u0940",
  "\u091c\u0941\u0928\u093e",
  "\u091c\u0941\u0928\u0941",
  "\u091c\u0941\u0932\u0941\u092e",
  "\u091c\u094d\u091e\u093e\u0928\u0939\u0947\u0930\u093e",
  "\u091c\u094d\u091e\u093e\u0928\u0940",
  "\u091c\u094d\u091e\u093e\u0928\u0941",
  "\u091c\u094d\u092f\u093e\u0938\u094d\u092e\u0940\u0928",
  "\u091d\u093f\u0928\u093e\u0932\u093e",
  "\u091f\u093e\u0938\u0940",
  "\u091f\u093f\u0928\u093e",
  "\u0921\u093f\u0932\u0941",
  "\u0921\u094b\u092e\u093e",
  "\u0921\u094b\u0932\u0940",
  "\u0921\u094b\u0932\u094d\u092e\u093e",
  "\u0924\u093e\u0928\u093f\u092f\u093e",
  "\u0924\u093e\u0930\u093e",
  "\u0924\u093e\u0930\u093e",
  "\u0924\u0941\u0932\u0938\u0940",
  "\u0924\u0947\u091c\u0938\u094d\u0935\u0940",
  "\u0924\u094b\u092f\u093e",
  "\u0924\u094b\u0930\u0923",
  "\u0925\u093f\u0928\u094d\u0932\u0947",
  "\u0926\u092e\u092f\u0928\u094d\u0924\u093f",
  "\u0926\u093f\u092a",
  "\u0926\u093f\u092a\u093e",
  "\u0926\u093f\u092a\u093e\u091e\u094d\n\u091c\u0932\u0940",
  "\u0926\u093f\u092a\u093f\u0938\u093e",
  "\u0926\u093f\u0932",
  "\u0926\u0940\u0915\u094d\u0937\u093e",
  "\u0926\u0941\u0930\u094d\u0917\u093e",
  "\u0926\u0947\u091a\u0947\u0928",
  "\u0926\u0947\u092c\u0915\u0940",
  "\u0926\u0947\u0935\u0915\u0940",
  "\u0926\u0947\u0935\u0940",
  "\u0927\u0928\u092e\u093e\u092f\u093e",
  "\u0927\u0928\u094d\u091c\u0941",
  "\u0927\u0928\u094d\u0936\u094d\n\u0935\u0930\u0940",
  "\u0927\u0930\u094d\u092e",
  "\u0928\u0917\u093f\u0928\u093e",
  "\u0928\u092e\u094d\u0930\u0924\u093e",
  "\u0928\u093e\u0924\u0940",
  "\u0928\u093e\u0928\u0941",
  "\u0928\u093e\u0930\u0928",
  "\u0928\u093e\u0930\u093e\u092f\u0923",
  "\u0928\u093f\u0915\u093f\u0924\u093e",
  "\u0928\u093f\u0915\u094d\u0937\u093e",
  "\u0928\u093f\u0927\u0940",
  "\u0928\u093f\u092d\u093e",
  "\u0928\u093f\u092e\u093e",
  "\u0928\u093f\u092e\u094d\u092e\u0940",
  "\u0928\u093f\u092e\u094d\u092e\u0940",
  "\u0928\u093f\u0930\u091c\u093e",
  "\u0928\u093f\u0930\u093e",
  "\u0928\u093f\u0930\u093e",
  "\u0928\u093f\u0930\u0941",
  "\u0928\u093f\u0930\u0941",
  "\u0928\u093f\u0930\u094d\u092e\u0932",
  "\u0928\u093f\u0930\u094d\u092e\u0932\u093e",
  "\u0928\u093f\u0930\u094d\u092e\u0932\u093e",
  "\u0928\u093f\u0932\u0941",
  "\u0928\u093f\u0936\u0930\u0924",
  "\u0928\u0940\u0930\u093e",
  "\u092a\u0926\u092e",
  "\u092a\u0926\u094d\n\u092e\u093e",
  "\u092a\u0930\u0932\u093e",
  "\u092a\u0932\u093f\u0938\u093e",
  "\u092a\u0935\u093f\u0924\u094d\u0930\u093e",
  "\u092a\u093e\u0930\u094d\u0935\u0924\u0940",
  "\u092a\u093e\u0930\u094d\u0935\u0924\u0940",
  "\u092a\u093f\u0928\u0941",
  "\u092a\u0941\u091c\u0928",
  "\u092a\u0941\u091c\u093e",
  "\u092a\u0941\u091c\u093e",
  "\u092a\u0941\u091c\u093e",
  "\u092a\u0941\u0928",
  "\u092a\u0941\u0937\u094d\u092a\u093e",
  "\u092a\u0941\u0937\u094d\n\u0937\u093e",
  "\u092a\u0942\u091c\u093e",
  "\u092a\u0942\u0930\u094d\u0923",
  "\u092a\u0942\u0930\u094d\u0923",
  "\u092a\u0942\u0930\u094d\u0923\u092e\u093e\u092f\u093e",
  "\u092a\u0947\u0928\u094d\u091c\u0940\u0932\u093e",
  "\u092a\u094d\u0930\u0924\u093f\u0924\u093f",
  "\u092a\u094d\u0930\u0924\u093f\u092d\u093e",
  "\u092a\u094d\u0930\u0924\u093f\u092d\u093e",
  "\u092a\u094d\u0930\u0924\u093f\u0938\u0930\u093e",
  "\u092a\u094d\u0930\u092e\u093f\u0932\u093e",
  "\u092a\u094d\u0930\u092e\u093f\u0932\u093e",
  "\u092a\u094d\u0930\u0935\u093f\u0928\u093e",
  "\u092a\u094d\u0930\u093f\u0924\u0940",
  "\u092a\u094d\u0930\u093f\u092f\u093e",
  "\u092a\u094d\u0930\u093f\u092f\u093e",
  "\u092a\u094d\u0930\u093f\u092f\u093e",
  "\u092a\u094d\u0930\u093f\u092f\u093e",
  "\u092a\u094d\u0930\u093f\u092f\u093e",
  "\u092a\u094d\u0930\u0947\u092e\u093e",
  "\u092a\u094d\u0930\u0947\u0930\u0923\u093e",
  "\u092a\u094d\u0930\u0947\u0930\u0923\u093e",
  "\u092b\u0941\u092e\u093f\u0928\u0940",
  "\u092b\u0941\u0932\u093e\u0935\u0924\u0940",
  "\u092b\u094c\u091c\u093f\u092f\u093e",
  "\u092c\u0928\u093f\u0924\u093e",
  "\u092c\u0928\u094d\u0926\u0928\u093e",
  "\u092c\u092c\u093f\u0924\u093e",
  "\u092c\u0935\u093f\u0924\u093e",
  "\u092c\u093f\u0923\u093e",
  "\u092c\u093f\u0928\u093f\u0924\u093e",
  "\u092c\u093f\u092e\u0932\u093e",
  "\u092c\u0940\u0923\u093e",
  "\u092c\u0941\u0926\u094d\u0927",
  "\u092c\u0948\u0937\u094d\u0923\u0935\u0940",
  "\u092d\u0917\u0935\u0924\u0940",
  "\u092d\u0917\u0935\u0924\u0940",
  "\u092d\u0917\u0935\u0924\u0940",
  "\u092d\u0917\u0935\u0924\u0940",
  "\u092d\u0917\u0935\u0924\u0940",
  "\u092d\u0935\u093e\u0928\u0940",
  "\u092d\u093e\u0930\u0924\u0940",
  "\u092d\u093e\u0935\u0928\u093e",
  "\u092d\u0941\u0935\u0928",
  "\u092d\u094b\u091c\u0915\u0932\u093e",
  "\u092e\u0902\u0917\u0932\u0940",
  "\u092e\u091e\u094d\u091c\u0941",
  "\u092e\u0923\u093f",
  "\u092e\u0927\u0941",
  "\u092e\u0928",
  "\u092e\u0928",
  "\u092e\u0928\u093f\u0932\u093e",
  "\u092e\u0928\u093f\u0937\u093e",
  "\u092e\u0928\u093f\u0937\u093e",
  "\u092e\u0928\u0940\u0937\u093e",
  "\u092e\u0928\u094d\u091c\u0941",
  "\u092e\u0928\u094d\u091c\u0941",
  "\u092e\u0928\u094d\u091c\u0941",
  "\u092e\u0928\u094d\u0926\u0940\u0930\u093e",
  "\u092e\u092e\u0924\u093e",
  "\u092e\u092e\u0924\u093e",
  "\u092e\u092f\u0919\u094d\u0916\u0941",
  "\u092e\u0932\u094d\u0932\u0940\u0915\u093e",
  "\u092e\u0932\u094d\u0932\u0940\u0915\u093e",
  "\u092e\u0939\u093e\u0935\u0924\u0940",
  "\u092e\u093e\u0927\u0941\u0930\u0940",
  "\u092e\u093e\u0928\u0938\u0940",
  "\u092e\u093f\u0919\u092e\u0930",
  "\u092e\u093f\u0920\u0941",
  "\u092e\u093f\u0928\u093e",
  "\u092e\u093f\u0928\u093e",
  "\u092e\u093f\u0928\u093e",
  "\u092e\u093f\u0928\u093e",
  "\u092e\u093f\u0928\u0941",
  "\u092e\u093f\u0930\u093e",
  "\u092e\u093f\u0930\u093e",
  "\u092e\u093f\u0936\u094d\u0930\u0940",
  "\u092e\u0940\u0928\u093e",
  "\u092e\u0940\u0928\u093e",
  "\u092e\u0940\u0930\u093e",
  "\u092e\u0940\u0930\u093e",
  "\u092e\u0941\u0928\u092e\u0941\u0928",
  "\u092e\u0942\u0928",
  "\u092e\u0947\u0928\u093e",
  "\u092e\u0947\u0928\u094d\n\u0916\u0941",
  "\u092e\u0947\u0930\u093f\u0928\u093e",
  "\u092e\u0947\u0930\u093f\u0928\u093e",
  "\u092e\u0948\u092f\u093e",
  "\u092e\u094b\u0939\u093f\u0928\u0940",
  "\u092f\u094b\u0919\u092e\u0940",
  "\u0930\u0902\u091c\u0940\u0924\u093e",
  "\u0930\u0915\u0940\u0932\u093e",
  "\u0930\u091a\u093f\u0924\u093e",
  "\u0930\u091c\u0928\u0940",
  "\u0930\u091c\u0928\u0940",
  "\u0930\u091c\u093f\u0924\u093e",
  "\u0930\u0928\u094d\u091c\u0928\u093e",
  "\u0930\u092c\u093f\u0928\u093e",
  "\u0930\u092c\u0940\u0928\u093e",
  "\u0930\u092e\u093e",
  "\u0930\u092e\u093e",
  "\u0930\u092e\u093e",
  "\u0930\u092e\u093f\u0924\u093e",
  "\u0930\u092e\u093f\u0924\u093e",
  "\u0930\u092e\u093f\u0932\u093e",
  "\u0930\u0935\u093f\u0928\u093e",
  "\u0930\u0935\u093f\u0936\u094d\u0930\u0940",
  "\u0930\u0936\u094d\u092e\u093f",
  "\u0930\u0936\u094d\u092e\u093f",
  "\u0930\u0936\u094d\n\u092e\u0940",
  "\u0930\u093e\u091c\u0932\u0915\u094d\u0937\u094d\u092e\u0940",
  "\u0930\u093e\u091c\u094d\u092f\u0932\u0915\u094d\u0937\u094d\u092e\u0940",
  "\u0930\u093e\u0927\u093e",
  "\u0930\u093e\u0927\u093f\u0915\u093e",
  "\u0930\u093e\u092e",
  "\u0930\u093e\u092e",
  "\u0930\u093e\u092e",
  "\u0930\u093f\u0924\u093e",
  "\u0930\u093f\u0924\u093e",
  "\u0930\u093f\u0924\u093e",
  "\u0930\u093f\u0924\u0941",
  "\u0930\u093f\u092e\u093e",
  "\u0930\u0940\u0924\u093e",
  "\u0930\u0940\u0924\u093e",
  "\u0930\u0940\u0924\u093e",
  "\u0930\u0940\u0928\u093e",
  "\u0930\u0941\u091c\u093e",
  "\u0930\u0941\u0926\u094d\u0930",
  "\u0930\u0941\u092a\u093e",
  "\u0930\u0941\u092a\u093e",
  "\u0930\u0941\u092a\u093e",
  "\u0930\u0941\u092a\u093e",
  "\u0930\u0941\u092a\u093e",
  "\u0930\u0941\u092a\u093e",
  "\u0930\u0941\u092a\u093e",
  "\u0930\u0941\u0935\u093f\u0928\u093e",
  "\u0930\u0947\u0916\u093e",
  "\u0930\u0947\u0923\u0941",
  "\u0930\u0947\u0935\u0924\u0940",
  "\u0930\u094b\u091c\u093f\u0928\u093e",
  "\u0932\u0915\u094d\u0937\u094d\u092e\u0940",
  "\u0932\u0915\u094d\u0937\u094d\u092e\u0940",
  "\u0932\u0915\u094d\u0937\u094d\u092e\u0940",
  "\u0932\u0915\u094d\u0937\u094d\u092e\u0940",
  "\u0932\u0915\u094d\u0937\u094d\n\u092e\u0940",
  "\u0932\u0915\u094d\u0937\u094d\n\u092e\u0940",
  "\u0932\u0932\u093f\u0924\u093e",
  "\u0932\u093f\u0932\u093e\u0932\u0915\u094d\u0937\u094d\u092e\u0940",
  "\u0932\u0940\u0932\u093e",
  "\u0932\u094d\u0939\u093e\u091c\u0940",
  "\u0935\u0928\u094d\u0926\u093f\u0928\u0940",
  "\u0935\u0930\u094d\u0937\u093e",
  "\u0935\u0935\u0940",
  "\u0935\u093f\u091c\u092f\u093e",
  "\u0935\u093f\u091c\u092f\u093e",
  "\u0935\u093f\u0926\u094d\u092f\u093e",
  "\u0935\u093f\u0927\u094d\u092f\u093e",
  "\u0935\u093f\u0928\u093e",
  "\u0935\u093f\u0928\u093e",
  "\u0935\u093f\u0928\u093f\u0924\u093e",
  "\u0935\u093f\u0928\u093f\u0924\u093e",
  "\u0935\u093f\u092d\u093e",
  "\u0935\u093f\u092e\u0932\u093e",
  "\u0935\u093f\u092e\u0932\u093e",
  "\u0935\u093f\u092e\u0932\u093e",
  "\u0935\u093f\u092e\u0932\u093e",
  "\u0935\u093f\u0937\u094d\n\u0923\u0941",
  "\u0935\u093f\u0937\u094d\n\u0923\u0941",
  "\u0936\u0930\u094d\u092e\u093f\u0932\u093e",
  "\u0936\u0930\u094d\u092e\u093f\u0932\u093e",
  "\u0936\u0930\u094d\u092e\u093f\u0932\u093e",
  "\u0936\u0930\u094d\u092e\u093f\u0932\u093e",
  "\u0936\u0936\u0940",
  "\u0936\u0936\u0940",
  "\u0936\u0936\u0940",
  "\u0936\u0936\u0940",
  "\u0936\u093e\u0928\u094d\u0924\u093e",
  "\u0936\u093e\u0928\u094d\u0924\u093f",
  "\u0936\u093e\u0928\u094d\u0924\u0940",
  "\u0936\u093e\u0928\u094d\u0924\u0940",
  "\u0936\u093e\u0928\u094d\u0924\u0940",
  "\u0936\u093e\u0928\u094d\u0924\u0940",
  "\u0936\u093e\u0928\u094d\u0924\u0940",
  "\u0936\u093f\u0916\u093e",
  "\u0936\u093f\u0916\u093e",
  "\u0936\u093f\u0932\u093e",
  "\u0936\u093f\u0932\u0941",
  "\u0936\u0940\u0932\u093e",
  "\u0936\u0941\u092d\u0947\u091a\u094d\u091b\u093e",
  "\u0936\u0941\u0936\u093f\u0932\u093e",
  "\u0936\u0941\u0936\u093f\u0932\u093e",
  "\u0936\u0941\u0938\u093f\u0932\u093e",
  "\u0936\u094b\u092d\u093e",
  "\u0936\u094b\u092d\u093e",
  "\u0936\u094b\u092d\u093e",
  "\u0936\u094d\u0930\u0926\u094d\u0927\u093e",
  "\u0936\u094d\u0930\u0926\u094d\u0927\u093e",
  "\u0936\u094d\u0930\u0940\u092a\u094d\u0930\u093e\u092a\u094d\n\u0924\u0940",
  "\u0936\u094d\u0930\u0940\u092e\u0924\u0940",
  "\u0936\u094d\u0930\u0940\u092f\u093e",
  "\u0936\u094d\u0930\u0943\u0937\u094d\n\u091f\u093f",
  "\u0936\u094d\u0930\u0947\u092f\u0936\u0940",
  "\u0936\u094d\n\u092f\u093e\u092e\u093e",
  "\u0936\u094d\n\u0935\u0947\u0924\u093e",
  "\u0938\u0902\u0917\u093f\u0924\u093e",
  "\u0938\u0902\u0917\u093f\u0924\u093e",
  "\u0938\u0902\u0917\u0940\u0924\u093e",
  "\u0938\u091a\u093f\u0924\u093e",
  "\u0938\u091c\u0928\u093e",
  "\u0938\u0924\u094d\u092f",
  "\u0938\u0924\u094d\u092f\u0935\u094d\u0930\u0924\u093e",
  "\u0938\u092a\u0928\u093e",
  "\u0938\u092b\u0932\u0924\u093e",
  "\u0938\u092c\u0928\u092e",
  "\u0938\u092e\u093e\u0928\u0924\u093e",
  "\u0938\u092e\u0940\u0928\u093e",
  "\u0938\u092e\u094d\u092a\u0926\u093e",
  "\u0938\u0930\u0932\u093e",
  "\u0938\u0930\u0938\u094d\u0935\u0924\u0940",
  "\u0938\u0930\u0938\u094d\u0935\u0924\u0940",
  "\u0938\u0930\u0938\u094d\u0935\u0924\u0940",
  "\u0938\u0930\u0938\u094d\u0935\u0924\u0940",
  "\u0938\u0930\u0938\u094d\u0935\u0924\u0940",
  "\u0938\u0930\u093f\u0924\u093e",
  "\u0938\u0930\u093f\u0924\u093e",
  "\u0938\u0930\u093f\u0924\u093e",
  "\u0938\u0930\u093f\u0924\u093e",
  "\u0938\u0930\u093f\u0924\u093e",
  "\u0938\u0930\u0940\u0924\u093e",
  "\u0938\u0930\u0940\u0924\u093e",
  "\u0938\u0930\u094b\u091c",
  "\u0938\u0930\u094b\u091c",
  "\u0938\u0930\u094b\u091c\u093e",
  "\u0938\u0930\u094d\u092e\u093f\u0932\u093e",
  "\u0938\u0932\u093f\u0928\u093e",
  "\u0938\u0932\u093f\u092e\u093e",
  "\u0938\u0932\u094d\u092d\u093f\u092f\u093e",
  "\u0938\u0935\u093f\u0924\u093e",
  "\u0938\u0935\u093f\u0924\u093e",
  "\u0938\u0935\u093f\u0924\u093e",
  "\u0938\u0935\u093f\u0924\u093e",
  "\u0938\u0935\u093f\u0924\u093e",
  "\u0938\u0935\u093f\u0928\u093e",
  "\u0938\u093e\u0907\u092e\u0941",
  "\u0938\u093e\u0917\u0930",
  "\u0938\u093e\u0928\u0941",
  "\u0938\u093e\u0928\u0941",
  "\u0938\u093e\u0928\u0941",
  "\u0938\u093e\u0928\u094d\u0928\u093e\u0928\u0940",
  "\u0938\u093e\u0928\u094d\u0928\u093e\u0928\u0940",
  "\u0938\u093e\u0935\u093f\u0924\u094d\u0930\u0940",
  "\u0938\u093e\u0935\u093f\u0924\u094d\u0930\u0940",
  "\u0938\u093e\u0935\u093f\u0924\u094d\u0930\u0940",
  "\u0938\u093f\u0924\u093e",
  "\u0938\u093f\u0924\u093e",
  "\u0938\u093f\u0930\u0941",
  "\u0938\u0940\u0924\u093e",
  "\u0938\u0941\u0915\u0943\u0924\u0940",
  "\u0938\u0941\u0927\u093e",
  "\u0938\u0941\u0927\u093e",
  "\u0938\u0941\u0927\u093e",
  "\u0938\u0941\u0927\u093e",
  "\u0938\u0941\u0928",
  "\u0938\u0941\u0928\u093e\u092e",
  "\u0938\u0941\u0928\u093f\u0924\u093e",
  "\u0938\u0941\u0928\u093f\u0924\u093e",
  "\u0938\u0941\u0928\u093f\u0924\u093e",
  "\u0938\u0941\u092a\u094d\u0930\u092d\u093e",
  "\u0938\u0941\u092d\u0926\u094d\u0930\u093e",
  "\u0938\u0941\u092e\u0928",
  "\u0938\u0941\u092e\u093f\u0924\u094d\u0930\u093e",
  "\u0938\u0941\u092e\u093f\u0924\u094d\u0930\u093e",
  "\u0938\u0941\u092e\u093f\u0924\u094d\u0930\u093e",
  "\u0938\u0941\u092e\u0948\u092f\u093e",
  "\u0938\u0941\u0930\u0941\u091a\u0940",
  "\u0938\u0941\u0930\u0947\u0928\u094d\n\u0926\u094d\u0930\u093e",
  "\u0938\u0941\u0935\u0930\u094d\u0923\u093e",
  "\u0938\u0941\u0936\u093f\u0932\u093e",
  "\u0938\u0941\u0936\u093f\u0932\u093e",
  "\u0938\u0941\u0936\u093f\u0932\u093e",
  "\u0938\u0941\u0936\u093f\u0932\u093e",
  "\u0938\u0941\u0937\u092e\u093e",
  "\u0938\u0941\u0937\u094d\n\u092e\u093e",
  "\u0938\u0941\u0937\u094d\n\u092e\u093e",
  "\u0938\u0941\u0938\u093f\u0932\u093e",
  "\u0938\u0943\u091c\u0928\u093e",
  "\u0938\u0943\u091c\u0928\u093e",
  "\u0938\u0943\u091c\u0928\u093e",
  "\u0938\u094b\u0928\u0940",
  "\u0938\u094b\u0928\u0941",
  "\u0938\u094d\u092e\u0943\u0924\u0940",
  "\u0938\u094d\u092e\u0943\u0924\u0940",
  "\u0938\u094d\u0935\u0924\u093f",
  "\u0938\u094d\u0935\u0947\u091a\u094d\n\u091b\u093e",
  "\u0938\u094d\n\u0935\u0940\u0915\u0943\u0924\u0940",
  "\u0939\u0928\u0940",
  "\u0939\u0930\u093f",
  "\u0939\u093f\u092e\u093e",
  "\u0939\u093f\u0930\u093e",
  "\u0939\u093f\u0930\u093e"
)

person_first_names_male_ne_np <- c(
  "\u0905\u0915\u094d\u0937\u092f",
  "\u0905\u091a\u094d\u092f\u0941\u0924",
  "\u0905\u091c\u092f",
  "\u0905\u091c\u092f",
  "\u0905\u0928\u0915",
  "\u0905\u0928\u093f\u0930",
  "\u0905\u0928\u093f\u0932",
  "\u0905\u0928\u093f\u0932",
  "\u0905\u0928\u093f\u0932",
  "\u0905\u0928\u093f\u0932",
  "\u0905\u0928\u093f\u0937",
  "\u0905\u0928\u0941\u092a",
  "\u0905\u0928\u0941\u092a",
  "\u0905\u0928\u094b\u091c",
  "\u0905\u092d\u093f\u0937\u0947\u0915",
  "\u0905\u092d\u093f\u0937\u0947\u0915",
  "\u0905\u092d\u093f\u0937\u0947\u0915",
  "\u0905\u092e\u093f\u0924",
  "\u0905\u092e\u093f\u0924",
  "\u0905\u092e\u093f\u0924",
  "\u0905\u092e\u093f\u0928",
  "\u0905\u092e\u0943\u0924",
  "\u0905\u092e\u0943\u0924",
  "\u0905\u0930\u0941\u0923",
  "\u0905\u0930\u0941\u0923",
  "\u0905\u0930\u094d\u091c\u0941\u0928",
  "\u0905\u0932\u0902\u0915\u093e\u0930",
  "\u0905\u0935\u0932\u094b\u0915",
  "\u0905\u0935\u093f\u0928\u093e\u0936",
  "\u0905\u0935\u093f\u0936\u0947\u0915",
  "\u0905\u0936\u094b\u0915",
  "\u0905\u0936\u094b\u0915",
  "\u0905\u0936\u094b\u0915",
  "\u0905\u0936\u094b\u0915",
  "\u0905\u0936\u094b\u0915",
  "\u0905\u0936\u094b\u092c",
  "\u0905\u0938\u093f\u0928",
  "\u0905\u0938\u094b\u0915",
  "\u0906\u0915\u093e\u0936",
  "\u0906\u0924\u094d\u092e\u0947\u0936",
  "\u0906\u0932\u094b\u0915",
  "\u0906\u0932\u094b\u0915",
  "\u0906\u0936\u092f",
  "\u0906\u0936\u093f\u0937",
  "\u0906\u0936\u093f\u0937",
  "\u0906\u0936\u093f\u0937",
  "\u0906\u0936\u093f\u0937",
  "\u0906\u0936\u093f\u0937",
  "\u0906\u0936\u0940\u0937",
  "\u0908\u092c\u094d\u0930\u093e\u0939\u0940\u092e",
  "\u0908\u0938\u0940",
  "\u0909\u091c\u094d\u091c\u094d\u0935\u0932",
  "\u0909\u0924\u094d\u0924\u092e",
  "\u0909\u0924\u094d\u0924\u092e",
  "\u0909\u0926\u094d\u0927\u0935",
  "\u0909\u0926\u094d\u0927\u0935",
  "\u0909\u092e\u0947\u0936",
  "\u0909\u092e\u094d\u092e\u0947\u0926",
  "\u090b\u0915\u0941",
  "\u090b\u0936\u0941",
  "\u090b\u0937\u093f",
  "\u090b\u0937\u093f\u0915\u0947\u0938",
  "\u090f\u0915",
  "\u0913\u092e",
  "\u0915\u092a\u093f\u0932",
  "\u0915\u092e\u0932",
  "\u0915\u092e\u0932",
  "\u0915\u0930\u0928",
  "\u0915\u0930\u0928",
  "\u0915\u0930\u094d\u092e\u093e",
  "\u0915\u0932\u094d\u092f\u093e\u0923",
  "\u0915\u093e\u091c\u093f",
  "\u0915\u093e\u091c\u0940",
  "\u0915\u093f\u0930\u0923",
  "\u0915\u093f\u0930\u0923",
  "\u0915\u093f\u0930\u0923",
  "\u0915\u093f\u0930\u0923",
  "\u0915\u093f\u0936\u0928",
  "\u0915\u093f\u0936\u094b\u0930",
  "\u0915\u093f\u0936\u094b\u0930",
  "\u0915\u093f\u0936\u094b\u0930",
  "\u0915\u0940\u0930\u094d\u0924\u093f",
  "\u0915\u0941\u092e\u093e\u0930",
  "\u0915\u0941\u092e\u093e\u0930",
  "\u0915\u0941\u0935\u0947\u0930",
  "\u0915\u0941\u0936\u0932",
  "\u0915\u0943\u091c\u0932",
  "\u0915\u0943\u0937\u094d\u0923",
  "\u0915\u0943\u0937\u094d\u0923",
  "\u0915\u0943\u0937\u094d\u0923\u092e\u093e\u0928",
  "\u0915\u0943\u0937\u094d\n\u0923",
  "\u0915\u0943\u0937\u094d\n\u0923",
  "\u0915\u0943\u0937\u094d\n\u0923",
  "\u0915\u0943\u0937\u094d\n\u0923",
  "\u0915\u0943\u0937\u094d\n\u0923",
  "\u0915\u0943\u0937\u094d\n\u0923",
  "\u0915\u0943\u0937\u094d\n\u0923",
  "\u0915\u0943\u0937\u094d\n\u0923",
  "\u0915\u0943\u0937\u094d\n\u0923",
  "\u0915\u0943\u0937\u094d\n\u0923",
  "\u0915\u0943\u0937\u094d\n\u0923",
  "\u0915\u0947\u0936\u0930",
  "\u0915\u0947\u0936\u0935",
  "\u0915\u0947\u0936\u0935",
  "\u0915\u0947\u0936\u0935",
  "\u0915\u0947\u0936\u0935\u0932\u093e\u0932",
  "\u0915\u0947\u0938\u0930",
  "\u0915\u094c\u0936\u0932",
  "\u0916\u0917\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u0916\u0921\u094d\u0917",
  "\u0917\u0923\u0947\u0936",
  "\u0917\u094b\u092a\u093e\u0932",
  "\u0917\u094b\u092a\u093e\u0932",
  "\u0917\u094b\u092a\u0940",
  "\u0917\u094b\u0935\u093f\u0928\u094d\u0926",
  "\u0917\u094b\u0935\u093f\u0928\u094d\u0926",
  "\u0917\u094b\u0935\u093f\u0928\u094d\u0926",
  "\u0917\u094c\u0924\u092e",
  "\u091a\u0928\u094d\u0926",
  "\u091a\u0928\u094d\u0926\u094d\u0930",
  "\u091a\u0928\u094d\u0926\u094d\u0930\u0947\u0936",
  "\u091a\u093f\u0930\u091e\u094d\u091c\u0940\u092c\u093f",
  "\u091a\u093f\u0930\u0928\u091c\u0940\u0935\u0940",
  "\u091a\u0948\u0924\u094d\u092f",
  "\u091b\u0935\u093f",
  "\u091b\u0947\u0935\u093e\u0919",
  "\u091c\u0917\u0928\u093e\u0925",
  "\u091c\u0917\u0928\u094d\u0928\u093e\u0925",
  "\u091c\u0917\u0928\u094d\u0928\u093e\u0925",
  "\u091c\u0917\u0935\u093f\u0930",
  "\u091c\u092f\u0928\u094d\u0924",
  "\u091c\u092f\u0928\u094d\u0926\u094d\u0930",
  "\u091c\u092f\u0930\u093e\u092e",
  "\u091c\u093f\u0924\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u091c\u0940\u092c\u0928",
  "\u091c\u0941\u0917\u0932",
  "\u091c\u094d\u091e\u093e\u0928",
  "\u091c\u094d\u091e\u093e\u0928\u0941",
  "\u091c\u094d\u091e\u093e\u0928\u0947\u0936\u094d\n\u0935\u0930",
  "\u091c\u094d\u092f\u094b\u0924\u0940",
  "\u091c\u094d\u092f\u094b\u0924\u0940",
  "\u091c\u094d\n\u092f\u094b\u092d\u093e\u0928",
  "\u091f\u0938\u0940",
  "\u091f\u093e\u0938\u0940",
  "\u091f\u093f\u0915\u093e",
  "\u091f\u0947\u0915",
  "\u0921\u093e.",
  "\u0921\u093e.",
  "\u0921\u093e.",
  "\u0921\u0947\u0928\u093f\u0938",
  "\u0924\u093f\u0930\u094d\u0925",
  "\u0924\u0947\u091c\u0936\u094d\n\u0935\u0940",
  "\u0924\u094b\u092a\u094d\u0932\u093e",
  "\u0924\u094b\u0932\u093e\u0930\u093e\u092e",
  "\u0924\u094d\u0930\u093f\u0930\u0924\u094d\n\u0928",
  "\u0925\u094b\u0915\u0947\u0932",
  "\u0926\u092e\u094b\u0926\u0930",
  "\u0926\u0930\u094d\u0936\u0928",
  "\u0926\u0935\u093e",
  "\u0926\u093e\u0935\u093e",
  "\u0926\u093f\u0917\u0935\u093f\u091c\u092f\u093e",
  "\u0926\u093f\u0928\u0947\u0936",
  "\u0926\u093f\u0928\u0947\u0938",
  "\u0926\u093f\u092a\u0915",
  "\u0926\u093f\u092a\u0915",
  "\u0926\u093f\u092a\u0915",
  "\u0926\u093f\u092a\u0915",
  "\u0926\u093f\u092a\u0915",
  "\u0926\u093f\u092a\u0915",
  "\u0926\u093f\u092a\u0915",
  "\u0926\u093f\u092a\u0915",
  "\u0926\u093f\u092a\u0915",
  "\u0926\u093f\u092a\u0915\u0938\u094d\u0935\u0930",
  "\u0926\u093f\u092a\u0940\u0928",
  "\u0926\u093f\u092a\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u0926\u093f\u092a\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u0926\u093f\u092a\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u0926\u093f\u092a\u0947\u0936",
  "\u0926\u093f\u092a\u0947\u0936",
  "\u0926\u093f\u0932\u093f\u092a",
  "\u0926\u093f\u0935\u093e\u0915\u0930",
  "\u0926\u0940\u092a\u0915",
  "\u0926\u0940\u092a\u0947\u0936",
  "\u0926\u0941\u0930\u094d\u0917\u093e",
  "\u0926\u0947\u0935",
  "\u0926\u0947\u0935\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u0926\u0947\u0935\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u0926\u0947\u0935\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u0926\u0947\u0935\u0947\u0928\u094d\n\u0926\u094d\u0930",
  "\u0926\u094d\u0935\u093e\u0930\u0940\u0915\u093e",
  "\u0927\u0930\u094d\u092e\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u0927\u093f\u0930\u091c",
  "\u0927\u094d\u0930\u0941\u0935",
  "\u0928\u092c\u093f\u0928",
  "\u0928\u092c\u093f\u0928\u094d\u0926\u094d\u0930",
  "\u0928\u0930\u092a\u0932",
  "\u0928\u0930\u092d\u0942\u092a\u093e\u0932",
  "\u0928\u0930\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u0928\u0930\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u0928\u0935\u0930\u093e\u091c",
  "\u0928\u0935\u093f\u0928",
  "\u0928\u0935\u093f\u0928",
  "\u0928\u093e\u0930\u093e\u092f\u0923",
  "\u0928\u093e\u0930\u093e\u092f\u0923",
  "\u0928\u093f\u092e\u0947\u0936",
  "\u0928\u093f\u0930\u091c",
  "\u0928\u093f\u0930\u091c",
  "\u0928\u093f\u0930\u094b\u091c",
  "\u0928\u093f\u0930\u094d\u092d\u092f",
  "\u0928\u093f\u0930\u094d\u092e\u0932",
  "\u0928\u093f\u0930\u094d\u092e\u0947\u0936",
  "\u092a\u0902\u0915\u091c",
  "\u092a\u0902\u091a",
  "\u092a\u0935\u0928",
  "\u092a\u0935\u0928",
  "\u092a\u093e\u0930\u0938",
  "\u092a\u093e\u0938\u093e\u0919\u094d\u0917",
  "\u092a\u0941\u0930\u0941\u0937\u094b\u0924\u094d\u0924\u092e",
  "\u092a\u0941\u0930\u094d\u0923\u092d\u0915\u094d\n\u0924",
  "\u092a\u0941\u0932\u0915\u093f\u0924",
  "\u092a\u0941\u0937\u094d\n\u092a",
  "\u092a\u094d\u0930\u0915\u093e\u0936",
  "\u092a\u094d\u0930\u0915\u093e\u0936",
  "\u092a\u094d\u0930\u0915\u093e\u0936",
  "\u092a\u094d\u0930\u0915\u093e\u0936",
  "\u092a\u094d\u0930\u0915\u093e\u0938",
  "\u092a\u094d\u0930\u091c\u0940\u0924",
  "\u092a\u094d\u0930\u091c\u094d\u091e\u093e\u0928",
  "\u092a\u094d\u0930\u091c\u094d\u0935\u0932",
  "\u092a\u094d\u0930\u0926\u093f\u092a",
  "\u092a\u094d\u0930\u0926\u094d\u092e\u0941\u092e\u094d\u0928",
  "\u092a\u094d\u0930\u092b\u0941\u0932\u094d\u0932",
  "\u092a\u094d\u0930\u092d\u0941",
  "\u092a\u094d\u0930\u092e\u0947\u0936\u094d\n\u0935\u0930",
  "\u092a\u094d\u0930\u092e\u094b\u0926",
  "\u092a\u094d\u0930\u0932\u094d\n\u0939\u093e\u0926",
  "\u092a\u094d\u0930\u0935\u093f\u0923",
  "\u092a\u094d\u0930\u0935\u0947\u0936",
  "\u092a\u094d\u0930\u0936\u093e\u0928\u094d\u0924",
  "\u092a\u094d\u0930\u0936\u093e\u0928\u094d\u0928",
  "\u092a\u094d\u0930\u0938\u0919\u094d\u0917",
  "\u092a\u094d\u0930\u0947\u092e",
  "\u092b\u0923\u093f\u0928\u094d\u0926\u094d\u0930",
  "\u092c\u0926\u094d\u0930\u093f",
  "\u092c\u0926\u094d\u0930\u0940",
  "\u092c\u0926\u094d\u0930\u0940",
  "\u092c\u0928\u0935\u093e\u0930\u0940",
  "\u092c\u092c\u093f",
  "\u092c\u092c\u093f",
  "\u092c\u0932\u0915\u093f\u0938\u0928",
  "\u092c\u0932\u0930\u093e\u092e",
  "\u092c\u0932\u094d\u0932\u0941",
  "\u092c\u0938\u0928\u094d\u0924",
  "\u092c\u093e\u0938\u0941",
  "\u092c\u093e\u0938\u0941",
  "\u092c\u093f\u0915\u093e\u0936",
  "\u092c\u093f\u0915\u093e\u0938",
  "\u092c\u093f\u0930\u093e\u091f",
  "\u092c\u0941\u0926\u094d\u0927\u093f",
  "\u092c\u0941\u0927\u094d\u0926",
  "\u092d\u0930\u0924",
  "\u092d\u0930\u0924",
  "\u092d\u0930\u0924",
  "\u092d\u0935\u093f\u0928\u094d\n\u0926\u094d\u0930",
  "\u092d\u093e\u0907",
  "\u092d\u0941\u092e\u093e",
  "\u092d\u0948\u092f\u093e",
  "\u092d\u0948\u0930\u0935\u0932\u093e\u0932",
  "\u092d\u094b\u0932\u093e",
  "\u092e\u0902\u091c\u093f\u0932",
  "\u092e\u0923\u0940",
  "\u092e\u0923\u0940\u0930\u093e\u091c",
  "\u092e\u0926\u0928",
  "\u092e\u0926\u0928",
  "\u092e\u0926\u0928",
  "\u092e\u0928\u093f\u0937",
  "\u092e\u0928\u0940\u0937",
  "\u092e\u0928\u094b\u091c",
  "\u092e\u0928\u094b\u091c",
  "\u092e\u0928\u094b\u091c",
  "\u092e\u0928\u094b\u091c",
  "\u092e\u0928\u094b\u091c",
  "\u092e\u0928\u094b\u0939\u0930",
  "\u092e\u0928\u094b\u0939\u0930",
  "\u092e\u0928\u094d\u0928\u093e",
  "\u092e\u092f\u0941\u0936",
  "\u092e\u0939\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u092e\u0939\u0947\u0936",
  "\u092e\u0939\u0947\u0936",
  "\u092e\u0939\u0947\u0936",
  "\u092e\u0939\u0947\u0936",
  "\u092e\u0939\u0947\u0936",
  "\u092e\u093e\u0927\u0935",
  "\u092e\u093e\u0927\u0935",
  "\u092e\u093e\u0932\u091a\u0928\u094d\u0926",
  "\u092e\u093f\u0924\u094d\u0930",
  "\u092e\u093f\u0928\u0930\u093e\u091c",
  "\u092e\u0941\u0915\u0941\u0928\u094d\u0926",
  "\u092e\u0941\u0915\u0941\u0928\u094d\n\u0926",
  "\u092e\u0941\u0915\u0947\u0936",
  "\u092e\u0941\u0916\u094d\u092f\u093e",
  "\u092e\u0941\u0930\u093e\u0930\u0940\u0932\u093e\u0932",
  "\u092e\u0947\u0918",
  "\u092e\u0948\u0924\u094d\u0930\u0940",
  "\u092e\u094b\u0924\u0940",
  "\u092e\u094b\u0924\u0940",
  "\u092e\u094b\u0939\u0928",
  "\u092e\u094b\u0939\u0928",
  "\u092e\u094b\u0939\u0928",
  "\u092f\u0936",
  "\u092f\u093e\u092e",
  "\u092f\u0941\u0935\u0930\u093e\u091c",
  "\u092f\u094b\u0917\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u0930\u091c\u0924",
  "\u0930\u0924\u0928",
  "\u0930\u0924\u094d\n\u0928",
  "\u0930\u092e\u0923",
  "\u0930\u092e\u0947\u0936",
  "\u0930\u092e\u0947\u0936",
  "\u0930\u0935\u093f",
  "\u0930\u0935\u093f",
  "\u0930\u0935\u093f",
  "\u0930\u0935\u093f\u0928",
  "\u0930\u0935\u093f\u0928\u094d\u0926\u094d\u0930",
  "\u0930\u0935\u093f\u0928\u094d\u0926\u094d\u0930",
  "\u0930\u0935\u093f\u0928\u094d\u0926\u094d\u0930",
  "\u0930\u0935\u093f\u0928\u094d\u0926\u094d\u0930",
  "\u0930\u093e\u0918\u0935",
  "\u0930\u093e\u091c",
  "\u0930\u093e\u091c\u0915\u0941\u092e\u093e\u0930",
  "\u0930\u093e\u091c\u0928",
  "\u0930\u093e\u091c\u0928",
  "\u0930\u093e\u091c\u093f\u0935",
  "\u0930\u093e\u091c\u0940\u0935",
  "\u0930\u093e\u091c\u0941",
  "\u0930\u093e\u091c\u0941",
  "\u0930\u093e\u091c\u0941",
  "\u0930\u093e\u091c\u0941",
  "\u0930\u093e\u091c\u0941",
  "\u0930\u093e\u091c\u0941",
  "\u0930\u093e\u091c\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u0930\u093e\u091c\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u0930\u093e\u091c\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u0930\u093e\u091c\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u0930\u093e\u091c\u0947\u0936",
  "\u0930\u093e\u091c\u0947\u0936",
  "\u0930\u093e\u091c\u0947\u0936",
  "\u0930\u093e\u091c\u0947\u0936",
  "\u0930\u093e\u091c\u0947\u0936",
  "\u0930\u093e\u091c\u0947\u0936",
  "\u0930\u093e\u092e",
  "\u0930\u093e\u092e",
  "\u0930\u093e\u092e",
  "\u0930\u093e\u092e",
  "\u0930\u093e\u092e",
  "\u0930\u093e\u092e",
  "\u0930\u093e\u092e",
  "\u0930\u093e\u092e",
  "\u0930\u093e\u092e",
  "\u0930\u093e\u092e\u091a\u0928\u094d\u0926\u094d\u0930",
  "\u0930\u093e\u092e\u091c\u093e\u0928",
  "\u0930\u093e\u092e\u0936\u0930\u0923",
  "\u0930\u093e\u0939\u0941\u0932",
  "\u0930\u093e\u0939\u0941\u0932",
  "\u0930\u093e\u094d\u091c\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u0930\u0941\u092a\u0947\u0936",
  "\u0930\u094b\u091c\u093f\u0928",
  "\u0930\u094b\u091c\u0940\u0928",
  "\u0930\u094b\u092e\u0947\u0928\u094d\n\u0926\u094d\u0930",
  "\u0930\u094b\u0939\u0928",
  "\u0930\u094c\u0928\u0915",
  "\u0932\u0915\u094d\u0937\u094d\u092e\u0923",
  "\u0932\u0915\u094d\u0937\u094d\u092e\u0940",
  "\u0932\u0915\u094d\u0937\u094d\n\u092e\u0923",
  "\u0932\u0935",
  "\u0932\u093e\u0932",
  "\u0932\u093f\u091f\u0928",
  "\u0935\u0938\u0928\u094d\u0924",
  "\u0935\u093f\u0915\u093e\u0938",
  "\u0935\u093f\u0915\u094d\u0930\u092e",
  "\u0935\u093f\u091c\u092f",
  "\u0935\u093f\u091c\u0947\u0936",
  "\u0935\u093f\u0927\u094d\u092f\u093e\u092e\u093e\u0928",
  "\u0935\u093f\u0928\u093f\u0932",
  "\u0935\u093f\u0928\u094b\u0926",
  "\u0935\u093f\u0928\u094b\u0926",
  "\u0935\u093f\u0930\u092d\u0926\u094d\u0930",
  "\u0935\u093f\u0930\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u0935\u093f\u0935\u0947\u0915",
  "\u0935\u093f\u0935\u0947\u0915",
  "\u0935\u093f\u0935\u0947\u0915",
  "\u0935\u093f\u0936\u094d\n\u0935",
  "\u0935\u093f\u0937\u094d\u0923\u0941",
  "\u0935\u093f\u0937\u094d\n\u0923\u0941",
  "\u0935\u0941\u0937\u094d\n\u0915\u0930",
  "\u0936\u0902\u0915\u0930",
  "\u0936\u0902\u0915\u0930",
  "\u0936\u0902\u0915\u0930",
  "\u0936\u0902\u0915\u0930",
  "\u0936\u0915\u094d\u0924\u093f",
  "\u0936\u091a\u093f\u0928\u094d\u0926\u094d\u0930",
  "\u0936\u0930\u0926",
  "\u0936\u0930\u0926",
  "\u0936\u0930\u0926",
  "\u0936\u0936\u0940",
  "\u0936\u093e\u0928\u094d\u0924",
  "\u0936\u093e\u0939\u093f\u0926",
  "\u0936\u093f\u0935",
  "\u0936\u093f\u0935",
  "\u0936\u0941\u0915\u094d\u0930",
  "\u0936\u0941\u0936\u093e\u0928\u094d\u0924",
  "\u0936\u0941\u0936\u093f\u0932",
  "\u0936\u0947\u0932\u0947\u0928\u094d\n\u0926\u094d\u0930",
  "\u0936\u0948\u0932\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u0936\u0948\u0932\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u0936\u0948\u0932\u0947\u0938",
  "\u0936\u094d\u092f\u093e\u092e",
  "\u0936\u094d\u0930\u0940\u091c\u0919\u094d\u0917",
  "\u0936\u094d\u0930\u0940\u0935\u0924\u094d\u0938",
  "\u0936\u094d\u0930\u0947\u092f\u0938",
  "\u0936\u094d\n\u092f\u093e\u092e",
  "\u0936\u094d\n\u092f\u093e\u092e\u0930\u093e\u091c",
  "\u0938\u0902\u0915\u0930",
  "\u0938\u0902\u091c\u092f",
  "\u0938\u0902\u091c\u092f",
  "\u0938\u0902\u091c\u093f\u0935",
  "\u0938\u0902\u091c\u093f\u0935",
  "\u0938\u0902\u091c\u0940\u092c",
  "\u0938\u0902\u091c\u0940\u0935",
  "\u0938\u0902\u0926\u093f\u092a",
  "\u0938\u0917\u0941\u0928",
  "\u0938\u091c\u0928",
  "\u0938\u091c\u0947\u0928\u094d\n\u0926\u094d\u0930",
  "\u0938\u0928\u094d\u091c\u092f",
  "\u0938\u0928\u094d\u091c\u092f",
  "\u0938\u0928\u094d\u091c\u0940\u092c",
  "\u0938\u0928\u094d\u0924\u094b\u0937",
  "\u0938\u092b\u0930\u093e\u091c",
  "\u0938\u092e\u0941\u0928\u094d\n\u0926\u094d\u0930",
  "\u0938\u092e\u094d\u092a\u0941\u0930\u094d\u0923",
  "\u0938\u0930\u094b\u091c",
  "\u0938\u0930\u094b\u091c",
  "\u0938\u0930\u094b\u091c",
  "\u0938\u0930\u094d\u0935\u0947\u0936",
  "\u0938\u093e\u0917\u0930",
  "\u0938\u093e\u0928\u0941",
  "\u0938\u093f\u0926\u094d\u0927\u093f",
  "\u0938\u0940\u0924\u093e\u0930\u093e\u092e",
  "\u0938\u0941\u091c\u0928",
  "\u0938\u0941\u091c\u0928",
  "\u0938\u0941\u0926\u0928",
  "\u0938\u0941\u0926\u0930\u094d\u0936\u0928",
  "\u0938\u0941\u0927\u093f\u0930",
  "\u0938\u0941\u0928\u093f\u0932",
  "\u0938\u0941\u0928\u093f\u0932",
  "\u0938\u0941\u0928\u093f\u0932",
  "\u0938\u0941\u0928\u093f\u0932",
  "\u0938\u0941\u0928\u094d\u0926\u0930",
  "\u0938\u0941\u092e\u0928",
  "\u0938\u0941\u092e\u0928",
  "\u0938\u0941\u0930\u091c",
  "\u0938\u0941\u0930\u091c",
  "\u0938\u0941\u0930\u091c",
  "\u0938\u0941\u0930\u0947\u0928",
  "\u0938\u0941\u0930\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u0938\u0941\u0930\u0947\u0928\u094d\n\u0926\u094d\u0930",
  "\u0938\u0941\u0930\u0947\u0936",
  "\u0938\u0941\u0930\u0947\u0936",
  "\u0938\u0941\u0930\u0947\u0936",
  "\u0938\u0941\u0930\u0947\u0936",
  "\u0938\u0941\u0935\u0930\u094d\u0923",
  "\u0938\u0941\u0935\u0930\u094d\u0923",
  "\u0938\u0941\u0935\u094b\u0927",
  "\u0938\u0941\u0936\u093e\u0928\u094d\u0924",
  "\u0938\u0941\u0936\u093f\u0932",
  "\u0938\u0941\u0936\u093f\u0932",
  "\u0938\u0943\u091c\u0928",
  "\u0938\u0947\u0916\u0930",
  "\u0938\u0948\u092c\u0940",
  "\u0938\u094b\u092e",
  "\u0938\u094c\u0930\u092c",
  "\u0938\u094c\u0930\u092d",
  "\u0938\u094d\u0935\u093e\u0917\u0924",
  "\u0938\f\u0902\u091c\u092f",
  "\u0939\u0930\u093f",
  "\u0939\u0930\u093f",
  "\u0939\u0930\u093f",
  "\u0939\u0930\u093f\u0939\u0930",
  "\u0939\u0930\u094d\u0915",
  "\u0939\u093f\u0930\u093e",
  "\u0939\u093f\u0930\u093e",
  "\u0939\u093f\u0930\u093e",
  "\u0939\u093f\u0930\u0947\u0928\u094d\u0926\u094d\u0930",
  "\u0939\u0947\u092e\u0928",
  "\u0939\u0947\u092e\u0930\u093e\u091c"
)

person_first_names_ne_np <- c(
  person_first_names_male_ne_np,
  person_first_names_female_ne_np
)

person_last_names_ne_np <- c(
  "\u0905\u0917\u094d\u0930\u0935\u093e\u0932",
  "\u0928\u0947\u092a\u093e\u0932",
  "\u0928\u094d\u092f\u094c\u092a\u093e\u0928\u0947",
  "\u092e\u0939\u0930\u094d\u091c\u0928",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0925\u093e\u092a\u093e",
  "\u0932\u093e\u092e\u093e",
  "\u0916\u0921\u094d\u0917\u0940",
  "\u0936\u093e\u0939",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u092e\u093e\u0928\u0928\u094d\n\u0927\u0930",
  "\u0905\u0917\u094d\u0930\u0935\u093e\u0932",
  "\u0925\u093e\u092a\u093e",
  "\u0930\u093f\u092e\u093e\u0932",
  "\u0905\u0917\u094d\u0930\u0935\u093e\u0932",
  "\u0938\u0930\u0940\u092f\u093e",
  "\u0925\u093e\u092a\u093e",
  "\u0926\u0941\u0917\u0932",
  "\u092e\u0939\u0930\u094d\u091c\u0928",
  "\u092c\u0947\u0917\u093e\u092e\u0940",
  "\u0938\u093f\u0902\u0939",
  "\u0917\u0941\u0930\u0941\u0919\u094d\u0917",
  "\u092a\u0928\u094d\n\u0924",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u092a\u093e\u0923\u094d\u0921\u0947",
  "\u092e\u0939\u0930\u094d\u091c\u0928",
  "\u091c\u0948\u0928",
  "\u0936\u093e\u0915\u094d\u092f",
  "\u0905\u0917\u094d\u0930\u0935\u093e\u0932",
  "\u0925\u093e\u092a\u093e",
  "\u092a\u093e\u0923\u094d\n\u0921\u0947",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u0930\u093e\u091c\u0915\u0930\u094d\u0923\u093f\u0915\u093e\u0930",
  "\u0930\u0947\u0917\u094d\u092e\u0940",
  "\u0938\u0930\u093f\u092f\u093e",
  "\u092a\u094b\u0916\u0930\u0947\u0932",
  "\u0915\u093e\u0930\u094d\u0915\u0940",
  "\u0905\u0917\u094d\u0930\u0935\u093e\u0932",
  "\u092d\u091f\u094d\u091f\u0930\u093e\u0908",
  "\u092a\u094c\u0921\u094d\u092f\u093e\u0932",
  "\u0905\u0917\u094d\u0930\u0935\u093e\u0932",
  "\u092a\u093e\u0923\u094d\u0921\u0947",
  "\u0909\u092a\u093e\u0927\u094d\u092f\u093e\u092f",
  "\u0930\f\u091c\u093f\u0924\u0915\u093e\u0930",
  "\u0905\u0927\u093f\u0915\u093e\u0930\u0940",
  "\u092a\u093e\u0923\u094d\u0921\u0947",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u092a\u093e\u0923\u094d\n\u0921\u0947",
  "\u0905\u0917\u094d\u0930\u0935\u093e\u0932",
  "\u092e\u0941\u0938\u094d\n\u0932\u0940\u092e",
  "\u0917\u0941\u0930\u0941\u0919\u094d\u0917",
  "\u0915\u0915\u094d\u0937\u092a\u0924\u0940",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u092e\u093e\u0938\u094d\u0915\u0947",
  "(\u0915\u094d\u0937\u0947\u0924\u094d\u0930\u0940)",
  "\u0925\u093e\u092a\u093e",
  "\u0938\u093e\u092a\u0915\u094b\u091f\u093e",
  "\u092c\u094b\u0925\u0930\u093e",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u092d\u0941\u0938\u093e\u0932",
  "\u092a\u0928\u094d\u0924",
  "(\u092a\u093e\u0923\u094d\u0921\u0947)",
  "\u091f\u093f\u092c\u094d\u0930\u0947\u0935\u093e\u0932",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u092c\u0947\u0917\u093e\u0928\u0940",
  "\u092a\u0928\u0947\u0930\u0941",
  "\u0936\u094d\u0930\u0947\u0937\u094d\u0920",
  "\u0930\u093e\u0920\u094c\u0930",
  "\u0917\u0941\u0930\u0941\u0919",
  "\u092a\u093e\u0923\u094d\u0921\u0947",
  "\u092e\u0939\u0930\u094d\u091c\u0928",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u0932\u093e\u092e\u093e",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0925\u093e\u092a\u093e",
  "\u0930\u093e\u0923\u093e",
  "\u0926\u0941\u0917\u0921",
  "\u092a\u094d\n\u092f\u093e\u0915\u0941\u0930\u0947\u0932",
  "\u0905\u0917\u094d\u0930\u0935\u093e\u0932",
  "\u0905\u0927\u093f\u0915\u093e\u0930\u0940",
  "\u091c\u094b\u0936\u0940",
  "\u0917\u0941\u0930\u0941\u0919\u094d\u0917",
  "\u0938\u093f\u0932\u0935\u093e\u0932",
  "\u0938\u093f\u0932\u094d\u0935\u093e\u0932",
  "\u092a\u093e\u0923\u094d\u0921\u0947",
  "\u092a\u094c\u0921\u094d\u092f\u093e\u0932",
  "\u0918\u093f\u092e\u093f\u0930\u0947",
  "\u0915\u094d\u0937\u0947\u0924\u094d\u0930\u0940",
  "\u0915\u0930\u094d\u092e\u093e\u091a\u093e\u0930\u094d\u092f",
  "\u0915\u0947.\u0938\u0940.",
  "\u0925\u093e\u092a\u093e",
  "\u092e\u0939\u0930\u094d\u091c\u0928",
  "\u0918\u093f\u092e\u093f\u0930\u0947",
  "\u0921\u0902\u0917\u094b\u0932",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0916\u0924\u094d\u0930\u0940",
  "\u0938\u093e\u0939\u0940",
  "\u0925\u093e\u092a\u093e",
  "\u092e\u0932\u094d\u0932",
  "\u0930\u093e\u091c\u0915\u0930\u094d\u0923\u093f\u0915\u093e\u0930",
  "\u0924\u093f\u0935\u093e\u0930\u0940",
  "\u092e\u0932\u094d\u0932",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0936\u094d\u0930\u0947\u0937\u094d\u0920",
  "\u092a\u094d\u0930\u091c\u093e\u092a\u0924\u093f",
  "\u0938\u093f\u091f\u094c\u0932\u093e",
  "\u0917\u093f\u0930\u0940",
  "(\u0927\u0947\u0915\u0947)",
  "\u0915\u0947.\u0938\u0940.",
  "\u0936\u0930\u094d\u092e\u093e",
  "\u0926\u0935\u093e\u0921\u0940",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u092e\u0932\u094d\u0932",
  "\u0938\u093f\u0932\u094d\u0935\u093e\u0932",
  "\u0936\u093e\u0915\u094d\u092f",
  "\u092a\u094d\u0930\u0927\u093e\u0928\u093e\u0919\u094d\u0917",
  "\u0938\u0941\u0935\u093e\u0932",
  "\u091c\u0948\u0928",
  "\u0930\u093f\u092e\u093e\u0932",
  "\u092a\u094c\u0921\u0947\u0932",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u091c\u094b\u0936\u0940",
  "\u0917\u0941\u0930\u0941\u0919\u094d\u0917",
  "\u092a\u094c\u0921\u0947\u0932",
  "\u0906\u091a\u093e\u0930\u094d\u092f",
  "\u0924\u093f\u0935\u093e\u0930\u0940",
  "\u092e\u0939\u0930\u094d\u091c\u0928",
  "\u0926\u0941\u0917\u0921",
  "\u0915\u0947.\u0938\u0940",
  "\u0915\u0947.\u0938\u0940",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u0930\u093e\u0923\u093e",
  "\u0927\u0928\u093e\u0935\u0924",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u0935\u091c\u094d\u0930\u093e\u091a\u093e\u0930\u094d\u092f",
  "\u0915\u0915\u094d\u0937\u092a\u0924\u093f",
  "\u092c\u0947\u0917\u093e\u0928\u0940",
  "\u092d\u091f\u094d\u091f\u0930\u093e\u0908",
  "\u092d\u0941\u091c\u0942",
  "\u0918\u0932\u0947",
  "\u0917\u0941\u0930\u0941\u0919\u094d\u0917",
  "\u092c\u0917\u093e\u0932\u0947",
  "\u092a\u094b\u0916\u0930\u0947\u0932",
  "\u0925\u093e\u092a\u093e",
  "\u0925\u093e\u092a\u093e",
  "\u092e\u0939\u0924\u094b",
  "\u0932\u094b\u0939\u0928\u0940",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0936\u093e\u0939\u0940",
  "\u0909\u0915\u094d\u092f\u093e\u0935",
  "\u0926\u0941\u0917\u0921",
  "\u0930\u093e\u091c\u0915\u0930\u094d\u0923\u093f\u0915\u093e\u0930",
  "\u0917\u0941\u0930\u0941\u0919\u094d\u0917",
  "\u0936\u0930\u094d\u092e\u093e",
  "\u091c\u0948\u0928",
  "\u0917\u0941\u0930\u0941\u0919",
  "\u092c\u0938\u094d\u0928\u0947\u0924",
  "\u0935\u091c\u094d\u0930\u093e\u091a\u093e\u0930\u094d\u092f",
  "\u092e\u093e\u0928\u0928\u094d\n\u0927\u0930",
  "\u092e\u0948\u0928\u093e\u0932\u0940",
  "\u091a\u094c\u0932\u093e\u0917\u093e\u0908",
  "\u0928\u094d\u092f\u094c\u092a\u093e\u0928\u0947",
  "\u092e\u0939\u0930\u094d\u091c\u0928",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u0930\u093e\u091c\u0915\u0930\u094d\u0923\u093f\u0915\u093e\u0930",
  "\u0938\u093f\u0902\u0939",
  "\u0924\u0941\u0932\u093e\u0927\u0930",
  "\u0905\u0927\u093f\u0915\u093e\u0930\u0940",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0905\u092e\u093e\u0924\u094d\u092f",
  "\u092e\u0939\u0930\u094d\u091c\u0928",
  "\u0905\u0917\u094d\u0930\u0935\u093e\u0932",
  "\u0915\u0947.\u0938\u0940",
  "\u0905\u0917\u094d\u0930\u0935\u093e\u0932",
  "\u0905\u0927\u093f\u0915\u093e\u0930\u0940",
  "\u0928\u094d\u092f\u094c\u092a\u093e\u0928\u0947",
  "\u0932\u093e\u092e\u093e",
  "\u092a\u094c\u0921\u0947\u0932",
  "\u0936\u093e\u0939",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0936\u0930\u094d\u092e\u093e",
  "\u0936\u093e\u0915\u094d\u092f",
  "\u092a\u0930\u093e\u091c\u0941\u0932\u0940",
  "\u0936\u093e\u0939\u0940",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u092a\u094c\u0921\u0947\u0932",
  "\u0928\u094d\u092f\u094c\u092a\u093e\u0928\u0947",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u0938\u093f\u0902\u0939",
  "\u092d\u091f\u094d\u091f\u0930\u093e\u0908",
  "\u0938\u0941\u0928\u0941\u0935\u093e\u0930",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u091c\u0948\u0928",
  "\u0936\u093e\u0939",
  "\u0932\u094b\u0939\u0928\u0940",
  "\u0924\u0941\u0932\u093e\u0927\u0930",
  "\u0938\u093f\u0902\f\u0916\u0921\u093e",
  "\u092a\u094d\u0930\u091c\u093e\u092a\u0924\u093f",
  "\u092a\u094b\u0926\u094d\u0935\u093e\u0930",
  "\u0915\u0947.\u0938\u0940",
  "\u0936\u0930\u094d\u092e\u093e",
  "\u0936\u0930\u094d\u092e\u093e",
  "\u0936\u094d\u0930\u0947\u0937\u094d\u0920",
  "\u0938\u093f\u0902\u0918\u0932",
  "\u0915\u0947.\u0938\u0940.",
  "\u0926\u0947\u0909\u091c\u093e",
  "\u0926\u093e\u0939\u093e\u0932",
  "\u0916\u0928\u093e\u0932",
  "\u092a\u0928\u0947\u0930\u0941",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u0917\u094b\u092f\u0932",
  "\u091c\u094b\u0936\u0940",
  "\u0905\u092e\u093e\u0924\u094d\n\u092f",
  "\u0936\u0947\u0930\u094d\u092a\u093e",
  "\u0936\u094d\u0930\u0947\u0937\u094d\u0920",
  "\u092a\u094d\u0930\u0927\u093e\u0928\u093e\u0919",
  "\u092d\u093f\u092e\u0938\u0930\u093f\u092f\u093e",
  "\u0938\u0941\u0935\u093e\u0932",
  "\u0924\u0923\u094d\u0921\u0941\u0915\u093e\u0930",
  "\u0924\u0941\u0932\u093e\u0927\u0930",
  "\u0917\u0941\u0930\u093e\u0917\u093e\u0908",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u091a\u094d\u092f\u093e\u092e\u0947",
  "\u0938\u0940",
  "\u0917\u094c\u0924\u092e",
  "\u091c\u094b\u0936\u0940",
  "\u0936\u093e\u0939",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0936\u094d\u0930\u0947\u0937\u094d\u0920",
  "\u0917\u094c\u0924\u092e",
  "\u0938\u093e\u0939",
  "\u091c\u094b\u0936\u0940",
  "\u0917\u0941\u0930\u0941\u0919",
  "\u092e\u094b\u0915\u094d\u0924\u093e\u0928",
  "\u0930\u093e\u091c\u0915\u0930\u094d\u0923\u093f\u0915\u093e\u0930",
  "\u0938\u0941\u0935\u093e\u0932",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u092a\u0928\u094d\u0924",
  "\u0921\u0902\u0917\u094b\u0932",
  "\u0909\u092a\u093e\u0927\u094d\n\u092f\u093e\u092f",
  "\u092a\u094d\u0930\u0927\u093e\u0928",
  "\u0916\u0928\u093e\u0932",
  "(\u0928\u094d\u092f\u094c\u092a\u093e\u0928\u0947)",
  "\u092e\u093f\u0924\u094d\u0924\u0932",
  "\u0936\u0930\u094d\u092e\u093e",
  "\u0917\u0921\u0924\u094c\u0932\u093e",
  "\u0917\u094b\u092f\u0932",
  "\u0930\u0947\u0917\u094d\u092e\u0940",
  "\u0916\u0921\u094d\u0917\u0940",
  "\u0932\u094b\u0939\u0928\u0940",
  "\u092a\u093e\u0923\u094d\u0921\u0947\u092f",
  "\u0932\u094b\u0939\u0928\u0940",
  "\u092a\u093e\u0923\u094d\u0921\u0947",
  "\u0932\u093f\u092e\u094d\u092c\u0941",
  "\u0936\u093e\u0939\u0940",
  "\u0930\u093e\u091c\u0915\u0930\u094d\u0923\u093f\u0915\u093e\u0930",
  "\u0921\u0902\u0917\u094b\u0932",
  "\u0938\u093f\f\u0939",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0916\u0924\u094d\u0930\u0940",
  "\u0939\u093e\u092f\u093e\u091c\u0941",
  "\u092a\u093e\u0923\u094d\u0921\u0947",
  "\u0916\u0928\u093e\u0932",
  "\u0930\u093e\u091c\u0915\u0930\u094d\u0923\u093f\u0915\u093e\u0930",
  "\u0925\u093e\u092a\u093e",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0936\u093e\u0915\u094d\u092f",
  "\u092a\u094d\u0930\u091c\u093e\u092a\u0924\u0940",
  "\u0916\u0921\u094d\u0917\u0940",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u091c\u0948\u0928",
  "\u0905\u0917\u094d\u0930\u0935\u093e\u0932",
  "\u0917\u094c\u0924\u092e",
  "\u0930\u0938\u093e\u092f\u0932\u0940",
  "\u0916\u0921\u094d\u0917\u0940",
  "\u0938\u093f\u0932\u0935\u093e\u0932",
  "\u0936\u093e\u0939\u0940",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0936\u093e\u0939\u0940",
  "\u0930\u093e\u091c\u0915\u0930\u094d\u0923\u093f\u0915\u093e\u0930",
  "\u091c\u0948\u0928",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u091c\u094d\u091e\u0935\u093e\u0932\u0940",
  "\u092d\u093f\u092e\u0938\u0930\u0940\u092f\u093e",
  "\u0922\u0919\u094d\u0917\u0947\u0932",
  "\u092c\u0938\u094d\u0928\u0947\u0924",
  "\u092a\u094d\u092f\u093e\u0915\u0941\u0930\u0947\u0932",
  "\u092a\u093e\u0923\u094d\u0921\u0947",
  "\u0926\u0941\u0917\u0921",
  "\u0930\u093e\u091c\u0915\u0930\u094d\u0923\u093f\u0915\u093e\u0930",
  "\u092a\u093e\u0923\u094d\u0921\u0947",
  "\u0930\u093e\u091c\u0915\u0930\u094d\u0923\u093f\u0915\u093e\u0930",
  "\u0915\u0941\u0907\u0915\u0947\u0932",
  "\u0905\u0917\u094d\u0930\u0935\u093e\u0932",
  "\u0917\u0941\u0930\u0941\u0919\u094d\u0917",
  "\u0905\u0917\u094d\u0930\u0935\u093e\u0932",
  "\u092a\u094c\u0921\u0947\u0932",
  "\u0915\u0902\u0938\u093e\u0915\u093e\u0930",
  "\u0926\u0941\u0917\u0921",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u092d\u091f\u094d\u091f\u0930\u093e\u0908",
  "\u0915\u094d\u0937\u0947\u0924\u094d\u0930\u0940",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0928\u093e\u0939\u091f\u093e",
  "\u092c\u0938\u094d\u0928\u0947\u0924",
  "\u0930\u093e\u091c\u0915\u0930\u094d\u0923\u093f\u0915\u093e\u0930",
  "\u0915\u0947.\u0938\u0940.",
  "\u0915\u0947.\u0938\u0940.",
  "\u0917\u0941\u092a\u094d\n\u0924\u093e",
  "\u092c\u091c\u094d\u0930\u093e\u091a\u093e\u0930\u094d\u092f",
  "\u091c\u094b\u0936\u0940",
  "\u091c\u094d\u091e\u0935\u093e\u0932\u0940",
  "\u092a\u0928\u094d\u0924",
  "\u0938\u093f\u0939\u0902",
  "\u0917\u0941\u092a\u094d\n\u0924\u093e",
  "\u091c\u094b\u0936\u0940",
  "\u0936\u0930\u094d\u092e\u093e",
  "\u0915\u0947.\u0938\u0940",
  "\u0926\u0947\u0909\u091c\u093e",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0932\u094b\u0939\u0928\u0940",
  "\u0930\u0947\u0917\u094d\n\u092e\u0940",
  "\u0915\u094d\u0937\u0947\u0924\u094d\u0930\u0940",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u091a\u093e\u0932\u093f\u0938\u0947",
  "\u0939\u093e\u092f\u091c\u0941",
  "\u092e\u0928\u0928\u094d\u0927\u0930",
  "\u0936\u094d\u0930\u0947\u0937\u094d\u0920",
  "\u0915\u0947.\u0938\u0940.",
  "\u0917\u0941\u0930\u0941\u0919",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u0930\u093e\u0923\u093e",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u0915\u093e\u092c\u0930\u093e",
  "\u0936\u093e\u0939\u0940",
  "\u0930\u093e\u0920\u094c\u0930",
  "\u0909\u092a\u093e\u0927\u094d\u092f\u093e\u092f",
  "\u0916\u0928\u093e\u0932",
  "\u091a\u093e\u0932\u093f\u0938\u0947",
  "\u0924\u0941\u0932\u093e\u0927\u0930",
  "\u092e\u0917\u0930",
  "\u091c\u0948\u0928",
  "\u092e\u0932\u094d\n\u0932",
  "\u091c\u0948\u0928",
  "\u0930\u093e\u0920\u0940",
  "\u0905\u0927\u093f\u0915\u093e\u0930\u0940",
  "\u092a\u0928\u094d\n\u0924",
  "\u0917\u0941\u0930\u0941\u0919\u094d\u0917",
  "\u0925\u093e\u092a\u093e",
  "\u092a\u094c\u0921\u0947\u0932",
  "\u0938\u0941\u0935\u0947\u0926\u0940",
  "\u0905\u0927\u093f\u0915\u093e\u0930\u0940",
  "\u092e\u0941\u0938\u0932\u092e\u093e\u0928",
  "\u0915\u093f\u0932\u094d\u0932\u093e",
  "\u092e\u094b\u0915\u094d\u0924\u093e\u0928",
  "\u092c\u0938\u094d\u0928\u094d\u092f\u093e\u0924",
  "\u0905\u0927\u093f\u0915\u093e\u0930\u0940",
  "\u0936\u094d\u0930\u0947\u0937\u094d\u0920",
  "\u0924\u0941\u0932\u093e\u0927\u0930",
  "\u092c\u091c\u094d\u0930\u093e\u091a\u093e\u0930\u094d\u092f",
  "\u0926\u0947\u0909\u091c\u093e",
  "\u0936\u093e\u0915\u094d\u092f",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0917\u0941\u0930\u0941\u0919\u094d\u0917",
  "\u0932\u0947\u0916\u0915",
  "\u0916\u0921\u094d\u0915\u093e",
  "\u092e\u0939\u0930\u094d\u091c\u0928",
  "\u0915\u093e\u0930\u094d\u0915\u0940",
  "\u0925\u093e\u092a\u093e",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u092a\u0928\u094d\u0924",
  "\u0930\u093e\u0908",
  "\u092a\u093e\u0923\u094d\u0921\u0947",
  "\u0932\u093e\u092e\u093e",
  "\u0921\u0902\u0917\u094b\u0932",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u092a\u0928\u094d\n\u0924",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0936\u093e\u0939",
  "\u0932\u094b\u0939\u0928\u0940",
  "\u0926\u0941\u0917\u0921",
  "\u0932\u093e\u092e\u093e",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0936\u093e\u0939",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u0905\u0927\u093f\u0915\u093e\u0930\u0940",
  "\u092a\u093e\u0923\u094d\u0921\u0947",
  "\u0936\u093e\u0939",
  "\u0909\u092a\u093e\u0927\u094d\u092f\u093e\u092f",
  "\u0926\u0947\u0909\u091c\u093e",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u092c\u0947\u0917\u093e\u0928\u0940",
  "\u0936\u0930\u094d\u092e\u093e",
  "\u0917\u093f\u0930\u0940",
  "\u0917\u0941\u0930\u0941\u0919\u094d\u0917",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0925\u093e\u092a\u093e",
  "\u0930\u093e\u091c\u0915\u0930\u094d\u0923\u093f\u0915\u093e\u0930",
  "\u0906\u0932\u092e",
  "\u0905\u0927\u093f\u0915\u093e\u0930\u0940",
  "\u092e\u093e\u0928\u0928\u094d\n\u0927\u0930",
  "\u0936\u094d\u0930\u0947\u0937\u094d\u0920",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u092a\u093e\u0923\u094d\u0921\u0947",
  "\u0930\u0938\u093e\u092f\u0932\u0940",
  "\u0915\u0947.\u0938\u0940",
  "\u0930\u093e\u091c\u0915\u0930\u094d\u0923\u093f\u0915\u093e\u0930",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0922\u0915\u093e\u0932",
  "\u0920\u0941\u0915\u0930\u0940",
  "\u0922\u0941\u0919\u094d\u0917\u0947\u0932",
  "\u0930\u093e\u091c\u0915\u0930\u094d\u0923\u093f\u0915\u093e\u0930",
  "\u092d\u091f\u094d\u091f\u0930\u093e\u0908",
  "\u0930\u093e\u091c\u0915\u0930\u094d\u0923\u093f\u0915\u093e\u0930",
  "\u0936\u094d\u0930\u0947\u0937\u094d\u0920",
  "\u0928\u0947\u092a\u093e\u0932",
  "\u092e\u0939\u0930\u094d\u091c\u0928",
  "\u0917\u0941\u0930\u0941\u0919\u094d\u0917",
  "\u0936\u093e\u0939",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0938\u0924\u094d\u092f\u093e\u0932",
  "\u0938\u093f\u0902\u0939",
  "\u092e\u093e\u0928\u0928\n\u0927\u0930",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0928\u0947\u092a\u093e\u0932\u0940",
  "\u0936\u093e\u0939",
  "\u0936\u0902\u0915\u0930",
  "\u0938\u0941\u0928\u0941\u0935\u093e\u0930",
  "\u0906\u0932\u092e",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0930\u093e\u091c\u0915\u0930\u094d\u0923\u093f\u0915\u093e\u0930",
  "\u0924\u0941\u0932\u093e\u0927\u0930",
  "\u0926\u0947\u0909\u091c\u093e",
  "(\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920)",
  "\u091c\u094d\u091e\u0935\u093e\u0932\u0940",
  "\u0924\u0941\u0932\u093e\u0927\u0930",
  "\u0916\u0921\u094d\u0917\u0940",
  "\u092c\u091c\u094d\u0930\u093e\u091a\u093e\u0930\u094d\u092f",
  "\u092a\u0928\u094d\u0924",
  "\u0939\u093e\u092f\u091c\u0941",
  "\u0936\u094d\u0930\u0947\u0937\u094d\u0920",
  "\u0938\u093f\u0902\u0939",
  "\u0917\u094c\u0924\u092e",
  "\u092e\u093f\u0924\u094d\u0924\u0932",
  "\u0920\u0915\u0941\u0930\u0940",
  "\u0925\u093e\u092a\u093e",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u0928\u094d\u092f\u094c\u092a\u093e\u0928\u0947",
  "(\u0905\u092e\u093e\u0924\u094d\u092f)",
  "\u0932\u093e\u092e\u093e",
  "\u0938\u093f\u0902\u0939",
  "\u0925\u093e\u092a\u093e",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u0921\f\u0902\u0917\u094b\u0932",
  "\u092e\u093e\u0928\u0928\u094d\u0927\u0930",
  "\u0924\u0941\u0932\u093e\u0927\u0930",
  "\u0930\u0938\u093e\u0907\u0932\u0940",
  "\u0905\u0917\u094d\u0930\u0935\u093e\u0932",
  "\u091c\u0948\u0928",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0924\u093f\u0935\u093e\u0930\u0940",
  "\u0936\u094d\u0930\u0947\u0937\u094d\n\u0920",
  "\u0928\u094d\u092f\u094c\u092a\u093e\u0928\u0947",
  "\u0924\u093f\u0935\u093e\u0930\u0940",
  "\u091c\u0948\u0928",
  "\u0922\u0941\u0919\u094d\u0917\u0947\u0932",
  "\u092e\u0932\u094d\u0932",
  "\u0917\u093f\u0930\u0940",
  "\u0930\u093e\u091c\u0915\u0930\u094d\u0923\u093f\u0915\u093e\u0930",
  "\u0925\u093e\u092a\u093e",
  "\u0905\u0917\u094d\u0930\u0935\u093e\u0932",
  "\u0938\u093f\u091f\u094c\u0932\u093e",
  "\u0925\u093e\u092a\u093e",
  "\u0915\u0930\u094d\u092e\u093e\u091a\u093e\u0930\u094d\u092f",
  "\u0915\u093f\u0930\u093e\u0901\u0924",
  "\u0938\u093f\u0902\u0939",
  "\u0938\u093f\u0902\u0939",
  "\u091c\u094b\u0936\u0940",
  "\u0936\u093e\u0939\u0940",
  "\u0926\u093e\u0939\u093e\u0932",
  "\u092e\u0939\u0930\u094d\u091c\u0928",
  "\u092e\u0939\u0930\u094d\u091c\u0928",
  "\u091c\u094b\u0936\u0940",
  "\u0938\u093f\u0902\u0939",
  "\u091c\u094b\u0936\u0940"
)

person_prefixes_female_ne_np <- c(
  "\u0936\u094d\u0930\u0940\u092e\u0924\u0940",
  "\u0938\u0941\u0936\u094d\u0930\u0940"
)
person_prefixes_male_ne_np <- c(
  "\u0936\u094d\u0930\u0940",
  "\u0936\u094d\u0930\u0940\u092e\u093e\u0928"
)
person_prefixes_ne_np <- c(person_prefixes_female_ne_np, person_prefixes_male_ne_np)

person_ne_np <- list(
  first_names = person_first_names_ne_np,
  first_names_female = person_first_names_female_ne_np,
  first_names_male = person_first_names_male_ne_np,
  last_names = person_last_names_ne_np,
  prefixes_female = person_prefixes_female_ne_np,
  prefixes_male = person_prefixes_male_ne_np,
  prefixes = person_prefixes_ne_np
)


#' @title Person Provider for Nepali (Nepal)
#' @inherit PersonProvider description details return
#' @export
#' @family ne
#' @family NP
#' @details Note for female and male components that we fall back on generic
#' versions if the locale
#' doesn't provide a male/female version.
#' e.g., if no female first name we use first
#' name
#' @examples
#' x <- PersonProvider_ne_NP$new()
#' x$locale
#' x$render()
#' x$first_name()
#' x$first_name_female()
#' x$first_name_male()
#' x$last_name()
#' x$last_name_female()
#' x$last_name_male()
PersonProvider_ne_NP <- R6::R6Class(
  "PersonProvider_ne_NP",
  inherit = PersonProvider,
  private = list(

    # person name formats
    formats = person_formats_ne_np,
    # person name data
    persons = person_ne_np,
    locale_ = "ne_NP"
  )
)
